@@ -2,7 +2,7 @@ package Algorithm::Evolutionary;
 
 use Carp qw(croak);
 
-our $VERSION = '0.79_2'; # Getting close to something
+our $VERSION = '0.82.1'; # Later than 1st GitHub version
 
 # Preloaded methods go here.
 
@@ -59,7 +59,7 @@ The main design principle of L<Algorithm::Evolutionary> is I<flexibility>: it
 should be very easy to create your own evolutionary algorithms using this library, and it should be
 also quite easy to program what's already there in the evolutionary
 computation community. Besides, the library classes should have
-persistence provided by XML modules, and, in some cases, YAML.
+persistence provided by YAML.
 
 The module allows to create simple evolutionary algorithms, as well
 as more complex ones, that interface with databases or with the
@@ -85,7 +85,7 @@ href='http://arxiv.org/abs/0908.0516'>Still doing evolutionary
 algorithms with Perl</a>, a gentle introduction to evolutionary
 algorithms in general and working with them using this module in particular.</p>
 
-<p>I have used this continously for my research all these year, and
+<p>I have used this library continously for my research all these year, and
 any search will return a number of papers; a journal article is
 already submitted, but meanwhile if you use it for any of your
 research, I would be very grateful if you quoted papers such as these
@@ -224,8 +224,6 @@ demos or adapting it to external fitness functions.
 
 =item L<Algorithm::Evolutionary::Op::CanonicalGA>.
 
-=item L<XML> for an explanation of the XML format used, although it's
-now rather obsolete. 
 
 =item L<POE::Component::Algorithm::Evolutionary> if you want to mix
 evolutionary algorithms with anything else easily.
