@@ -1,6 +1,7 @@
 use strict; # -*- cperl -*-
 use warnings;
 
+use lib qw( ../../../../lib );
 
 =head1 NAME
 
@@ -22,7 +23,7 @@ ONEMAX is the classical count-ones optimization function. Fast to implement, and
 
 package Algorithm::Evolutionary::Fitness::ONEMAX;
 
-our $VERSION = ( '$Revision: 2.1 $ ' =~ /(\d+\.\d+)/ ) ;
+our ($VERSION) = ( '$Revision: 3.0 $ ' =~ / (\d+\.\d+)/ ) ;
 
 use Carp qw( croak );
 use base qw(Algorithm::Evolutionary::Fitness::String);
@@ -47,10 +48,11 @@ sub onemax {
     if ( defined $cache->{$string} ) {
 	return $cache->{$string};
     }
-    my $num_ones;
-    while ( $string ) {
-      $num_ones += chop( $string );
-    }
+    my $num_ones = ($string =~ tr/1/1/);
+#    my $num_ones = grep( $_, split(//, $string ));
+#     while ( $string ) {
+#       $num_ones += chop( $string );
+#     }
     $cache->{$string} = $num_ones;
     return $num_ones;
 }
@@ -60,11 +62,10 @@ sub onemax {
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/02/04 20:43:14 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Fitness/ONEMAX.pm,v 2.1 2009/02/04 20:43:14 jmerelo Exp $ 
+  CVS Info: $Date: 2009/07/24 08:46:59 $ 
+  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Fitness/ONEMAX.pm,v 3.0 2009/07/24 08:46:59 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 2.1 $
-  $Name $
+  $Revision: 3.0 $
 
 =cut
 
