@@ -15,9 +15,9 @@ Algorithm::Evolutionary::Individual::BitString - Classic bitstring individual fo
 
     my $indi3 = new Algorithm::Evolutionary::Individual::BitString;
     $indi3->set( { length => 20 } );   #Sets values, but does not build the string
-    
+
     $indi3->randomize(); #Creates a random bitstring with length as above
- 
+
     print $indi3->Atom( 7 );       #Returns the value of the 7th character
     $indi3->Atom( 3 ) = 1;       #Sets the value
 
@@ -30,10 +30,8 @@ Algorithm::Evolutionary::Individual::BitString - Classic bitstring individual fo
 
     my @array = qw( 0 1 0 1 0 0 1 ); #Create a tied array
     tie my @vector, 'Algorithm::Evolutionary::Individual::BitString', @array;
-    print tied( @vector )->asXML();
 
     print $indi3->asString(); #Prints the individual
-    print $indi3->asXML() #Prints it as XML. See 
     print $indi3->as_yaml() #Change of convention, I know...
 
     my $gene_size = 5;
@@ -55,7 +53,7 @@ package Algorithm::Evolutionary::Individual::BitString;
 
 use Carp;
 
-our ($VERSION) =  ( '$Revision: 3.4 $ ' =~ /(\d+\.\d+)/ );
+our $VERSION =  '3.4';
 
 use base 'Algorithm::Evolutionary::Individual::String';
 
@@ -77,7 +75,7 @@ sub new {
   my $class = shift; 
   my $chars = [ '0', '1' ];
   my $self = 
-      Algorithm::Evolutionary::Individual::String::new( 'Algorithm::Evolutionary::Individual::BitString', $chars, @_ );
+      Algorithm::Evolutionary::Individual::String::new( $class, $chars, @_ );
   return $self;
 }
 
@@ -128,10 +126,4 @@ sub decode {
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2010/09/24 08:39:07 $ 
-  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Individual/BitString.pm,v 3.4 2010/09/24 08:39:07 jmerelo Exp $ 
-  $Author: jmerelo $ 
-  $Revision: 3.4 $
-  $Name $
-
 =cut
