@@ -4,7 +4,7 @@ use warnings;
 =head1 NAME
 
 Algorithm::Evolutionary::Op::Canonical_GA_NN - Canonical Genetic
-                 Algorithm that does not ranks population
+                 Algorithm that does not rank population
 
 =head1 SYNOPSIS
 
@@ -34,7 +34,7 @@ binary (a la crossover) they will be applied in turn to couples of the
 population.
 
 This is a fast version of the canonical GA, useful for large
-population, since it avoids the expensive rank operation. Roulette
+populations, since it avoids the expensive rank operation. Roulette
 wheel selection, still, is kind of slow.
 
 =head1 METHODS
@@ -45,8 +45,7 @@ package Algorithm::Evolutionary::Op::Canonical_GA_NN;
 
 use lib qw(../../..);
 
-our $VERSION =   sprintf "%d.%03d", q$Revision: 3.6 $ =~ /(\d+)\.(\d+)/g; 
-
+our $VERSION =   "3.6";
 
 use Carp;
 
@@ -139,9 +138,11 @@ sub apply ($) {
 
 =item L<Algorithm::Evolutionary::Fitness::Base>
 
+=item Of course, L<Algorithm::Evolutionary::Fitness::CanonicalGA>
+
 =back
 
-Probably you will also be able to find a
+You will also find a
     L<canonical-genetic-algorithm.pl> example within this
     bundle. Check it out for usage examples
 
@@ -150,12 +151,6 @@ Probably you will also be able to find a
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2011/02/14 06:55:36 $ 
-  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Canonical_GA_NN.pm,v 3.6 2011/02/14 06:55:36 jmerelo Exp $ 
-  $Author: jmerelo $ 
-  $Revision: 3.6 $
-  $Name $
-
 =cut
 
 "The truth is out there";
