@@ -3,8 +3,7 @@ use warnings;
 
 =head1 NAME
 
-    Algorithm::Evolutionary::Op::QuadXOver - n-point crossover operator; puts a part of the second operand
-                into the first operand; can be 1 or 2 points.
+Algorithm::Evolutionary::Op::QuadXOver - N-point crossover operator that changes operands
 
                  
 
@@ -12,7 +11,7 @@ use warnings;
 
   my $xmlStr3=<<EOC;
   <op name='QuadXOver' type='binary' rate='1'>
-    <param name='numPoints' value='3' /> #Max is 2, anyways
+    <param name='numPoints' value='2' /> #Max is 2, anyways
   </op>
   EOC
   my $ref3 = XMLin($xmlStr3);
@@ -22,10 +21,10 @@ use warnings;
 
   my $indi = new Algorithm::Evolutionary::Individual::BitString 10;
   my $indi2 = $indi->clone();
-  my $indi3 = $indi->clone();
+  my $indi3 = $indi->clone(); #Operands are modified, so better to clone them
   $op3->apply( $indi2, $indi3 );
 
-  my $op4 = new Algorithm::Evolutionary::Op::QuadXOver 3; #QuadXOver with 3 crossover points
+  my $op4 = new Algorithm::Evolutionary::Op::QuadXOver 1; #QuadXOver with 1 crossover points
 
 =head1 Base Class
 
@@ -44,7 +43,7 @@ package Algorithm::Evolutionary::Op::QuadXOver;
 
 use lib qw( ../../.. );
 
-our ($VERSION) = ( '$Revision: 2.1 $ ' =~ /(\d+\.\d+)/ );
+our $VERSION =   sprintf "%d.1%02d", q$Revision: 3.4 $ =~ /(\d+)\.(\d+)/g; # Hack for avoiding version mismatch
 
 use Carp;
 
@@ -57,7 +56,8 @@ our $ARITY = 2;
 =head2 apply( $parent_1, $parent_2 )
 
 Same as L<Algorithm::Evolutionary::Op::Crossover>, but changes
-parents, does not return anything
+parents, does not return anything; that is, $parent_1 and $parent_2
+interchange genetic material.
 
 =cut
 
@@ -65,16 +65,18 @@ sub  apply ($$){
   my $self = shift;
   my $victim = shift || croak "No victim here!";
   my $victim2 = shift || croak "No victim here!";
-  croak "Incorrect type ".(ref $victim) if !$self->check($victim);
-  croak "Incorrect type ".(ref $victim2) if !$self->check($victim2);
+#  croak "Incorrect type ".(ref $victim) if !$self->check($victim);
+#  croak "Incorrect type ".(ref $victim2) if !$self->check($victim2);
   my $minlen = (  length( $victim->{_str} ) >  length( $victim2->{_str} ) )?
 	 length( $victim2->{_str} ): length( $victim->{_str} );
-  my $pt1 = int( rand( $minlen ) );
-  my $range = 1 + int( rand( $minlen  - $pt1 ) );
-#  print "Puntos: $pt1, $range \n";
+  my $pt1 = 1+int( rand( $minlen - 1 ) ); # first crossover point shouldn't be 0
+  my $range;
   if ( $self->{_numPoints} > 1 ) {
-    $range =  int ( rand( length( $victim->{_str} ) - $pt1 ) );
+    $range= 1 + int( rand( $minlen  - $pt1 ) );
+  } else {
+    $range = $minlen - $pt1;
   }
+#  print "Puntos: $pt1, $range \n";
   my $str = $victim->{_str};
   substr( $victim->{_str}, $pt1, $range ) = substr( $victim2->{_str}, $pt1, $range );
   substr( $victim2->{_str}, $pt1, $range ) = substr( $str, $pt1, $range );
@@ -88,10 +90,10 @@ sub  apply ($$){
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/02/04 20:43:15 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/QuadXOver.pm,v 2.1 2009/02/04 20:43:15 jmerelo Exp $ 
+  CVS Info: $Date: 2010/12/08 17:34:22 $ 
+  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/QuadXOver.pm,v 3.4 2010/12/08 17:34:22 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 2.1 $
+  $Revision: 3.4 $
   $Name $
 
 =cut
