@@ -1,6 +1,8 @@
 use strict;
 use warnings;
 
+use lib qw( ../../../../lib ); # mainly to avoid syntax errors when saving
+
 =head1 NAME
 
 SimulatedAnnealing - An operator that performs the simulated annealing algorithm
@@ -15,7 +17,7 @@ SimulatedAnnealing - An operator that performs the simulated annealing algorithm
 
 =head1 Base Class
 
-L< Algorithm::Evolutionary::Op::Base| Algorithm::Evolutionary::Op::Base>
+L<Algorithm::Evolutionary::Op::Base>
 
 =head1 DESCRIPTION
 
@@ -27,7 +29,7 @@ Simulated Annealing
 
 package Algorithm::Evolutionary::Op::SimulatedAnnealing;
 
-our ($VERSION) = ( '$Revision: 3.0 $ ' =~ /(\d+\.\d+)/ ) ;
+our $VERSION = '3.1';
 use Carp;
 
 use Algorithm::Evolutionary::Op::LinearFreezer;
@@ -126,10 +128,4 @@ sub run ($) {
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/07/24 08:46:59 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/SimulatedAnnealing.pm,v 3.0 2009/07/24 08:46:59 jmerelo Exp $ 
-  $Author: jmerelo $ 
-  $Revision: 3.0 $
-  $Name $
-
 =cut
